@@ -14,15 +14,11 @@
 
 /// @date Sep 96
 
-#ifndef metkit_MarsExpandContext_H
-#define metkit_MarsExpandContext_H
-
-#include "eckit/memory/NonCopyable.h"
+#pragma once
 
 #include <iosfwd>
 
-namespace metkit {
-namespace mars {
+namespace metkit::mars {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -48,7 +44,4 @@ class DummyContext : public MarsExpandContext {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace mars
-}  // namespace metkit
-
-#endif
+}  // namespace metkit::mars
