@@ -22,31 +22,52 @@ namespace metkit {
 
 class Quantile {
 public:
-    Quantile(const std::string &value);
+
+    Quantile(const std::string& value);
     Quantile(long num, long den);
 
-	long num() {return num_;}
-	long den() {return den_;}
+    long num() const { return num_; }
+    long den() const { return den_; }
 
-	operator std::string();
+    operator std::string();
+
+    Quantile& operator+=(const long& rhs);
+    Quantile& operator-=(const long& rhs);
 
 protected:
 
-	void print(std::ostream& s) const;
+    void print(std::ostream& s) const;
 
 private:
+
     void check() const;
 
-	friend std::ostream& operator<<(std::ostream& s,const Quantile& q)
-		{ q.print(s); return s; }
+    friend std::ostream& operator<<(std::ostream& s, const Quantile& q) {
+        q.print(s);
+        return s;
+    }
 
 private:
-    long num_;
-    long den_;    
 
+    long num_;
+    long den_;
 };
 
+bool operator==(const Quantile& lhs, const Quantile& rhs);
+inline bool operator!=(const Quantile& lhs, const Quantile& rhs) {
+    return !(rhs == lhs);
+}
+bool operator<(const Quantile& lhs, const Quantile& rhs);
+inline bool operator>(const Quantile& lhs, const Quantile& rhs) {
+    return rhs < lhs;
+}
+inline bool operator<=(const Quantile& lhs, const Quantile& rhs) {
+    return !(lhs > rhs);
+}
+inline bool operator>=(const Quantile& lhs, const Quantile& rhs) {
+    return !(lhs < rhs);
+}
+
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace metkit
-
+}  // namespace metkit
