@@ -35,7 +35,7 @@ private:  // methods
     void print(std::ostream& out) const override;
     bool expand(const MarsExpandContext& ctx, std::string& value, const MarsRequest& request) const override;
 
-    StepRange parse(std::string& value) const;
+    StepRange parse(const std::string& value) const;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
