@@ -13,12 +13,11 @@
 
 #include <algorithm>
 
-#include "eckit/config/Resource.h"
-#include "eckit/serialisation/MemoryStream.h"
-#include "eckit/message/Message.h"
 #include "eckit/config/Resource.h"
 #include "eckit/config/YAMLConfiguration.h"
 #include "eckit/io/DataHandle.h"
+#include "eckit/message/Message.h"
+#include "eckit/serialisation/MemoryStream.h"
 #include "eckit/types/Types.h"
 #include "eckit/utils/StringTools.h"
 
@@ -32,17 +31,13 @@ namespace codes {
 
 //----------------------------------------------------------------------------------------------------------------------
 bool OdbDecoder::match(const eckit::message::Message& msg) const {
-    size_t len = msg.length();
+    size_t len             = msg.length();
     const unsigned char* p = static_cast<const unsigned char*>(msg.data());
-    return len >= 5 and (
-               (p[0] == 0xff and p[1] == 0xff and p[2] == 'O' and p[3] == 'D' and p[4] == 'A')
-           );
+    return len >= 5 and ((p[0] == 0xff and p[1] == 0xff and p[2] == 'O' and p[3] == 'D' and p[4] == 'A'));
 }
 
 
-
-void OdbDecoder::getMetadata(const eckit::message::Message& msg,
-                             eckit::message::MetadataGatherer& gather,
+void OdbDecoder::getMetadata(const eckit::message::Message& msg, eckit::message::MetadataGatherer& gather,
                              const eckit::message::GetMetadataOptions& options) const {
 
     std::unique_ptr<eckit::DataHandle> handle(msg.readHandle());
@@ -59,11 +54,10 @@ void OdbDecoder::getMetadata(const eckit::message::Message& msg,
 
         span.visit(setter);
     }
-
 }
 
 eckit::Buffer OdbDecoder::decode(const eckit::message::Message& msg) const {
-    NOTIMP; // Not relevant for MultIO hackathon. Implement as needed in future.
+    NOTIMP;  // Not relevant for MultIO hackathon. Implement as needed in future.
 }
 
 void OdbDecoder::print(std::ostream& s) const {
