@@ -12,13 +12,12 @@
 /// @date   Jan 2016
 /// @author Florian Rathgeber
 
-#include "eckit/types/Date.h"
-#include "metkit/hypercube/HyperCube.h"
-#include "metkit/mars/MarsRequest.h"
+#include <algorithm>
 
 #include "eckit/testing/Test.h"
 
-using namespace eckit::testing;
+#include "metkit/hypercube/HyperCube.h"
+#include "metkit/mars/MarsRequest.h"
 
 namespace metkit::mars::test {
 
@@ -35,8 +34,6 @@ CASE("test_metkit_hypercube") {
     EXPECT(cube.contains(r));
     EXPECT(cube.size() == 1);
     EXPECT(cube.vacantRequests().size() == 1);
-    EXPECT_EQUAL("sh", r.values("repres").at(0));
-    r.unsetValues("repres");
     EXPECT(!(r < *cube.vacantRequests().begin()));
     EXPECT(!(*cube.vacantRequests().begin() < r));
 }
@@ -51,8 +48,6 @@ CASE("test_metkit_hypercube_subset") {
     EXPECT(cube.size() == 2);
     EXPECT(cube.countVacant() == 2);
     EXPECT(cube.vacantRequests().size() == 1);
-    EXPECT_EQUAL("sh", r.values("repres").at(0));
-    r.unsetValues("repres");
     EXPECT(!(r < *cube.vacantRequests().begin()));
     EXPECT(!(*cube.vacantRequests().begin() < r));
 
@@ -60,15 +55,11 @@ CASE("test_metkit_hypercube_subset") {
         "retrieve,class=rd,type=an,stream=oper,levtype=pl,date=20191110,time=0000,step=0,expver=xxxy,domain=g,levelist="
         "500,param=138";
     MarsRequest r500 = MarsRequest::parse(text500);
-    EXPECT_EQUAL("sh", r500.values("repres").at(0));
-    r500.unsetValues("repres");
 
     const char* text600 =
         "retrieve,class=rd,type=an,stream=oper,levtype=pl,date=20191110,time=0000,step=0,expver=xxxy,domain=g,levelist="
         "600,param=138";
     MarsRequest r600 = MarsRequest::parse(text600);
-    EXPECT_EQUAL("sh", r600.values("repres").at(0));
-    r600.unsetValues("repres");
 
     EXPECT_THROWS(cube.contains(r));
     EXPECT(cube.contains(r500));
@@ -99,8 +90,6 @@ CASE("test_metkit_hypercube_request") {
     EXPECT(cube.size() == 4);
     EXPECT(cube.countVacant() == 4);
     EXPECT(cube.vacantRequests().size() == 1);
-    EXPECT_EQUAL("sh", r.values("repres").at(0));
-    r.unsetValues("repres");
     EXPECT(!(r < *cube.vacantRequests().begin()));
     EXPECT(!(*cube.vacantRequests().begin() < r));
 
@@ -108,15 +97,11 @@ CASE("test_metkit_hypercube_request") {
         "retrieve,class=rd,type=an,stream=oper,levtype=pl,date=20191110,time=0000,step=0,expver=xxxy,domain=g,levelist="
         "500,param=138";
     MarsRequest r500 = MarsRequest::parse(text500);
-    EXPECT_EQUAL("sh", r500.values("repres").at(0));
-    r500.unsetValues("repres");
 
     const char* text600 =
         "retrieve,class=rd,type=an,stream=oper,levtype=pl,date=20191110,time=0000,step=0,expver=xxxy,domain=g,levelist="
         "600,param=138";
     MarsRequest r600 = MarsRequest::parse(text600);
-    EXPECT_EQUAL("sh", r600.values("repres").at(0));
-    r600.unsetValues("repres");
 
     EXPECT_THROWS(cube.contains(r));
     EXPECT(cube.contains(r500));
@@ -139,16 +124,60 @@ CASE("test_metkit_hypercube_request") {
         "retrieve,class=rd,type=an,stream=oper,levtype=pl,date=20191110,time=0000,step=0,expver=xxxy,domain=g,levelist="
         "500/600,param=155";
     MarsRequest r155 = MarsRequest::parse(text155);
-    EXPECT_EQUAL("sh", r155.values("repres").at(0));
-    r155.unsetValues("repres");
     EXPECT(!(r155 < *cube.vacantRequests().begin()));
     EXPECT(!(*cube.vacantRequests().begin() < r155));
 }
 
-//-----------------------------------------------------------------------------
+CASE("test_metkit_hypercube_request METK-132") {
+    std::vector<std::string> keys = {"levelist", "param"};
+
+    MarsRequest r = MarsRequest::parse("retrieve,levelist=2/4/1/3/5,param=228038/235094/235077/235078");
+    metkit::hypercube::HyperCube cube{r};
+
+    // unset levelist 5 for params 235077/235094
+    cube.clear(MarsRequest::parse("retrieve,levelist=5,param=235077"));
+    cube.clear(MarsRequest::parse("retrieve,levelist=5,param=235094"));
+
+    std::vector<MarsRequest> expected_flat_requests = {
+        MarsRequest::parse("retrieve,levelist=1,param=228038"), MarsRequest::parse("retrieve,levelist=2,param=228038"),
+        MarsRequest::parse("retrieve,levelist=3,param=228038"), MarsRequest::parse("retrieve,levelist=4,param=228038"),
+        MarsRequest::parse("retrieve,levelist=5,param=228038"), MarsRequest::parse("retrieve,levelist=1,param=235077"),
+        MarsRequest::parse("retrieve,levelist=2,param=235077"), MarsRequest::parse("retrieve,levelist=3,param=235077"),
+        MarsRequest::parse("retrieve,levelist=4,param=235077"), MarsRequest::parse("retrieve,levelist=1,param=235094"),
+        MarsRequest::parse("retrieve,levelist=2,param=235094"), MarsRequest::parse("retrieve,levelist=3,param=235094"),
+        MarsRequest::parse("retrieve,levelist=4,param=235094"), MarsRequest::parse("retrieve,levelist=1,param=235078"),
+        MarsRequest::parse("retrieve,levelist=2,param=235078"), MarsRequest::parse("retrieve,levelist=3,param=235078"),
+        MarsRequest::parse("retrieve,levelist=4,param=235078"), MarsRequest::parse("retrieve,levelist=5,param=235078"),
+        // These two requests we have removed from the cube:
+        // MarsRequest::parse("retrieve,levelist=5,param=235077"),
+        // MarsRequest::parse("retrieve,levelist=5,param=235094"),
+    };
+
+    auto dense_requests = cube.vacantRequests();
+    EXPECT_EQUAL(dense_requests.size(), 2);
+
+    std::vector<MarsRequest> flattened_requests;
+    for (const auto& req : cube.vacantRequests()) {  // surely this should be requests, not vacantRequests... anyway...
+        auto flattened = req.split(keys);
+        for (const auto& f : flattened) {
+            flattened_requests.push_back(f);
+        }
+    }
+
+    EXPECT_EQUAL(flattened_requests.size(), 18);
+    EXPECT_EQUAL(flattened_requests.size(), expected_flat_requests.size());
+
+    // compare both vectors
+    std::sort(flattened_requests.begin(), flattened_requests.end());
+    std::sort(expected_flat_requests.begin(), expected_flat_requests.end());
+    for (size_t i = 0; i < expected_flat_requests.size(); ++i) {
+        EXPECT_EQUAL(flattened_requests[i].values("levelist"), expected_flat_requests[i].values("levelist"));
+        EXPECT_EQUAL(flattened_requests[i].values("param"), expected_flat_requests[i].values("param"));
+    }
+}
 
 }  // namespace metkit::mars::test
 
 int main(int argc, char** argv) {
-    return run_tests(argc, argv);
+    return eckit::testing::run_tests(argc, argv);
 }
